@@ -1,3 +1,4 @@
+
 .onLoad <- function(libname, pkgname) {
   op <- options()
   op.dplyr <- list(
@@ -6,8 +7,8 @@
   toset <- !(names(op.dplyr) %in% names(op))
   if (any(toset)) options(op.dplyr[toset])
 
-  ns <- ns_env("dplyr")
-  .Call(dplyr_init_library, ns_env())
+  .Call(dplyr_init_library, ns_env("dplyr"))
+
   invisible()
 }
 
