@@ -126,7 +126,7 @@ starwars %>%
 my_summarise <- function(data, group_var, summarise_var) {
   data %>%
     group_by(across({{ group_var }})) %>% 
-    summarise(across({{ group_var }}, mean))
+    summarise(across({{ summarise_var }}, mean))
 }
 
 ## -----------------------------------------------------------------------------
