@@ -51,12 +51,11 @@ test_that("distinct doesn't duplicate columns", {
   expect_named(df %>% group_by(a) %>% distinct(a), "a")
 })
 
-
 test_that("grouped distinct always includes group cols", {
   df <- tibble(g = c(1, 2), x = c(1, 2))
 
   out <- df %>% group_by(g) %>% distinct(x)
-  expect_equal(df, out)
+  expect_named(out, c("g", "x"))
 })
 
 test_that("empty grouped distinct equivalent to empty ungrouped", {
@@ -68,68 +67,6 @@ test_that("empty grouped distinct equivalent to empty ungrouped", {
   expect_equal(df1, df2)
 })
 
-test_that("distinct gives a warning when selecting an unknown column (#3140)", {
-  df <- tibble(g = c(1, 2), x = c(1, 2))
-
-  expect_warning(
-    distinct(df, aa),
-    glue("Trying to compute distinct() for variables not found in the data:
-         - `aa`
-         This is an error, but only a warning is raised for compatibility reasons.
-         The operation will return the input unchanged."),
-    fixed = TRUE
-  )
-  expect_warning(
-    distinct(df, .data$aa),
-    glue("Trying to compute distinct() for variables not found in the data:
-      - `aa`
-      This is an error, but only a warning is raised for compatibility reasons.
-      The operation will return the input unchanged."),
-    fixed = TRUE
-    )
-
-
-  expect_warning(
-    distinct(df, aa, x),
-    glue("Trying to compute distinct() for variables not found in the data:
-         - `aa`
-         This is an error, but only a warning is raised for compatibility reasons.
-         The following variables will be used:
-         - x"),
-    fixed = TRUE
-  )
-  expect_warning(
-    distinct(df, .data$aa, x),
-    glue("Trying to compute distinct() for variables not found in the data:
-      - `aa`
-      This is an error, but only a warning is raised for compatibility reasons.
-      The following variables will be used:
-      - x"),
-    fixed = TRUE
-    )
-
-  expect_warning(
-    distinct(df, g, aa, x),
-    glue("Trying to compute distinct() for variables not found in the data:
-         - `aa`
-         This is an error, but only a warning is raised for compatibility reasons.
-         The following variables will be used:
-         - g
-         - x"),
-    fixed = TRUE
-  )
-  expect_warning(
-    distinct(df, g, .data$aa, x),
-    glue("Trying to compute distinct() for variables not found in the data:
-      - `aa`
-      This is an error, but only a warning is raised for compatibility reasons.
-      The following variables will be used:
-      - g
-      - x"),
-    fixed = TRUE
-    )
-})
-
 test_that("distinct on a new, mutated variable is equivalent to mutate followed by distinct", {
   df <- tibble(g = c(1, 2), x = c(1, 2))
 
@@ -155,32 +92,8 @@ test_that("distinct on a dataframe or tibble with columns of type list throws an
   )
   df2 <- data.frame(x = 1:5, y = I(list(1:3, 2:4, 3:5, 4:6, 5:7)))
 
-  expect_warning(
-    expect_identical(df %>% distinct(), df %>% slice(c(1, 3, 5))),
-    "distinct() does not fully support columns of type `list`.\nList elements are compared by reference, see ?distinct for details.\nThis affects the following columns:\n- `b`",
-    fixed = TRUE
-  )
-  expect_warning(
-    expect_identical(df2 %>% distinct(), df2),
-    "distinct() does not fully support columns of type `list`.\nList elements are compared by reference, see ?distinct for details.\nThis affects the following columns:\n- `y`",
-    fixed = TRUE
-  )
-})
-
-test_that("distinct deals with Period and Interval from lubridate (#2568)", {
-  skip_if_not(requireNamespace("lubridate", quietly = TRUE))
-
-  df <- tibble(
-    x = lubridate::hm("10:30", "10:30", "0:0"),
-    y = c("apple", "apple", "tomato")
-  )
-  res <- distinct(df)
-  expect_equal(res, df[c(1, 3), ])
-
-  df <- tibble(
-    lubridate::interval(lubridate::ymd(20090201), lubridate::ymd(20090101))
-  )
-  expect_equal(df, distinct(df))
+  expect_identical(df2 %>% distinct(), df2)
+  expect_identical(df %>% distinct(), df %>% slice(c(1, 3, 5)))
 })
 
 test_that("distinct handles 0 columns edge case (#2954)", {
@@ -191,7 +104,65 @@ test_that("distinct handles 0 columns edge case (#2954)", {
   expect_equal(nrow(distinct(tibble())), 0L)
 })
 
-test_that("distinct respects the order of the given variables (#3195)",{
-  d <- data.frame(x=1:2, y=3:4)
-  expect_equal(names(distinct(d, y, x)), c("y", "x"))
+test_that("distinct preserves order of the input variables (#3195)",{
+  d <- data.frame(x = 1:2, y = 3:4)
+  expect_equal(names(distinct(d, y, x)), c("x", "y"))
+})
+
+test_that("distinct() understands both NA variants (#4516)", {
+  df <- data.frame(col_a = c(1, NA, NA))
+  df$col_a <- df$col_a+0
+  df$col_a[2] <- NA_real_
+  expect_equal(nrow(distinct(df)), 2L)
+
+  df_1 <- data.frame(col_a = c(1, NA))
+  df_2 <- data.frame(col_a = c(1, NA))
+
+  df_1$col_a <- df_1$col_a+0
+  df_2$col_a <- df_2$col_a+0
+
+  df_1$col_a[2] <- NA
+  expect_equal(nrow(setdiff(df_1, df_2)), 0L)
+})
+
+test_that("distinct() handles auto splicing", {
+  expect_equal(
+    iris %>% distinct(Species),
+    iris %>% distinct(data.frame(Species=Species))
+  )
+
+  expect_equal(
+    iris %>% distinct(Species),
+    iris %>% distinct(across(Species))
+  )
+
+  expect_equal(
+    iris %>% mutate(across(starts_with("Sepal"), round)) %>% distinct(Sepal.Length, Sepal.Width),
+    iris %>% distinct(across(starts_with("Sepal"), round))
+  )
+})
+
+test_that("distinct preserves grouping", {
+  gf <- group_by(tibble(x = c(1, 1, 2, 2), y = x), x)
+
+  i <- count_regroups(out <- distinct(gf))
+  expect_equal(i, 0)
+  expect_equal(group_vars(out), "x")
+
+  i <- count_regroups(out <- distinct(gf, x = x + 2))
+  expect_equal(i, 1)
+  expect_equal(group_vars(out), "x")
+})
+
+# Errors ------------------------------------------------------------------
+
+
+test_that("distinct gives a warning when selecting an unknown column (#3140)", {
+  df <- tibble(g = c(1, 2), x = c(1, 2))
+
+  verify_output(test_path("test-distinct-errors.txt"), {
+    df %>% distinct(aa, x)
+    df %>% distinct(aa, bb)
+    df %>% distinct(.data$aa)
+  })
 })
